%define anolis_release 1
%global _hardened_build 1

Name:          libwebp
Version:       1.3.2
Release:       %{anolis_release}%{?dist}
URL:           http://webmproject.org/
Summary:       Library and tools for the WebP graphics format
License:       BSD
Source0:       http://downloads.webmproject.org/releases/webp/%{name}-%{version}.tar.gz
Source1:       libwebp_jni_example.java
Patch0:        libwebp-freeglut.patch
Patch2:        libwebp-cmakedir.patch
Patch3:        libwebp-rpath.patch

BuildRequires: swig
BuildRequires: cmake gcc
BuildRequires: java-devel
BuildRequires: libpng-devel
BuildRequires: giflib-devel
BuildRequires: libtiff-devel
BuildRequires: libjpeg-devel
BuildRequires: freeglut-devel
BuildRequires: jpackage-utils

%description
Libwebp is an open-source library for encoding and decoding images in the WebP
image format. WebP is an image format developed by Google, which provides
superior compression and quality compared to other image formats like JPEG and
PNG.

The libwebp library includes various tools and APIs for working with WebP
images, including a command-line tool for converting images to and from the WebP
format, a decoder library for reading WebP images in various applications, and
an encoder library for creating WebP images.

Additionally, libwebp supports features like lossless and lossy compression,
transparency, and animation in WebP images. It is compatible with multiple
programming languages and platforms, including C, C++, Java, and Python, and is
widely used in various applications and websites that require fast and
efficient image processing.

%package tools
Summary:       The WebP command line tools

%description tools
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.

%package devel
Summary:       Development files for libwebp, a library for the WebP format
Requires:      %{name} = %{version}-%{release}

%description devel
WebP is an image format that does lossy compression of digital
photographic images. WebP consists of a codec based on VP8, and a
container based on RIFF. Webmasters, web developers and browser
developers can use WebP to compress, archive and distribute digital
images more efficiently.


%package java
Summary:       Java bindings for libwebp, a library for the WebP format
Requires:      %{name} = %{version}-%{release}
Requires:      java-headless
Requires:      jpackage-utils

%description java
Java bindings for libwebp.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup -p1

%build
%cmake
%cmake_build

cp %{SOURCE1} .
cd swig
rm -rf libwebp.jar libwebp_java_wrap.c
mkdir -p java/com/google/webp
swig -package com.google.webp  \
    -outdir java/com/google/webp \
    -ignoremissing -I../src -java \
    -o libwebp_java_wrap.c libwebp.swig

gcc %{__global_ldflags} %{optflags} -shared \
    -I/usr/lib/jvm/java/include \
    -I/usr/lib/jvm/java/include/linux \
    -I../src \
    -L../%{_vpath_builddir} -lwebp libwebp_java_wrap.c \
    -o libwebp_jni.so

cd java
javac com/google/webp/libwebp.java
jar cvf ../libwebp.jar com/google/webp/*.class

%install
%cmake_install

mkdir -p %{buildroot}/%{_libdir}/%{name}-java
cp swig/*.jar swig/*.so %{buildroot}/%{_libdir}/%{name}-java/

%check
%ctest

%files
%license COPYING
%{_libdir}/%{name}.so.7*
%{_libdir}/%{name}mux.so.3*
%{_libdir}/libsharpyuv.so.0*
%{_libdir}/%{name}demux.so.2*
%{_libdir}/%{name}decoder.so.3*

%files devel
%{_includedir}/webp/
%{_libdir}/%{name}.so
%{_libdir}/cmake/WebP/
%{_libdir}/%{name}mux.so
%{_libdir}/libsharpyuv.so
%{_libdir}/%{name}demux.so
%{_libdir}/%{name}decoder.so
%{_libdir}/pkgconfig/libwebp.pc
%{_libdir}/pkgconfig/libwebpmux.pc
%{_libdir}/pkgconfig/libsharpyuv.pc
%{_libdir}/pkgconfig/libwebpdemux.pc
%{_libdir}/pkgconfig/libwebpdecoder.pc

%files tools
%{_bindir}/cwebp
%{_bindir}/dwebp
%{_bindir}/vwebp
%{_mandir}/man*/*
%{_bindir}/webpmux
%{_bindir}/webpinfo
%{_bindir}/img2webp
%{_bindir}/gif2webp

%files java
%{_libdir}/%{name}-java/
%doc libwebp_jni_example.java

%files doc
%doc README.md PATENTS NEWS AUTHORS

%changelog
* Thu Sep 28 2023 Funda Wang <fundawang@yeah.net> - 1.3.2-1
- New version 1.3.2

* Wed Sep 13 2023 Funda Wang <fundawang@yeah.net> - 1.3.0-6
- Fix CVE-2023-4863

* Wed May 24 2023 Funda Wang <fundawang@yeah.net> - 1.3.0-5
- Fix CVE-2023-1999

* Thu Apr 13 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.3.0-4
- Optimize the spec

* Fri Mar 10 2023 Funda Wang <fundawang@yeah.net> - 1.3.0-3
- Drop mingw support

* Fri Jan 20 2023 Funda Wang <fundawang@yeah.net> - 1.3.0-2
- Rebuild for new libtiff

* Thu Jan 19 2023 Funda Wang <fundawang@yeah.net> - 1.3.0-1
- New version 1.3.0

* Mon Sep 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.2.4-1
- update to 1.2.4

* Thu Apr 07 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.2.2-1
- Init from upstream version 1.2.2

